@@ -17,11 +17,12 @@
  */
 
 #include <ctype.h>
+#include <string.h>
 
 #include <gtk/gtkalignment.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkeventbox.h>
-#include <gtk/gtkfilesel.h>
+#include <gtk/gtkfilechooserdialog.h>
 #include <gtk/gtkframe.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkhbbox.h>
@@ -31,6 +32,7 @@
 #include <gtk/gtknotebook.h>
 #include <gtk/gtkoptionmenu.h>
 #include <gtk/gtkradiobutton.h>
+#include <gtk/gtkstock.h>
 #include <gtk/gtkvbox.h>
 
 #include "gladeconfig.h"
@@ -70,17 +72,18 @@ static void glade_project_options_translatable_strings_toggled (GtkWidget *widge
 								GladeProjectOptions *options);
 static void glade_project_options_show_file_selection (GtkWidget *widget,
 						       gpointer data);
-static void glade_project_options_set_filename (GtkWidget *widget,
-						GladeProjectOptions *options);
+static void on_filesel_response (GtkWidget *widget,
+				 gint response_id,
+				 GladeProjectOptions *options);
 static void glade_project_options_ok (GtkWidget *widget,
 				      GladeProjectOptions *options);
 static gchar* get_entry_text (GtkWidget *entry);
 static gboolean glade_project_options_check_valid	(GladeProjectOptions *options);
 
-guint
+GType
 glade_project_options_get_type (void)
 {
-  static guint glade_project_options_type = 0;
+  static GType glade_project_options_type = 0;
 
   if (!glade_project_options_type)
     {
@@ -115,6 +118,19 @@ glade_project_options_class_init (GladeProjectOptionsClass * klass)
   object_class->destroy = glade_project_options_destroy;
 }
 
+static void
+set_accessible_description (GtkWidget *widget, const gchar *desc)
+{
+  AtkObject *atk_widget;
+
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  atk_widget = gtk_widget_get_accessible (widget);
+
+  if (desc)
+    atk_object_set_description (atk_widget, desc);
+}
+ 
 
 static void
 glade_project_options_init (GladeProjectOptions * options)
@@ -359,14 +375,17 @@ glade_project_options_init (GladeProjectOptions * options)
   menu = gtk_menu_new ();
   menuitem = gtk_menu_item_new_with_label ("GNU General Public License");
   gtk_widget_show (menuitem);
-  gtk_menu_append (GTK_MENU (menu), menuitem);
+  gtk_container_add (GTK_CONTAINER (menu), menuitem);
   gtk_option_menu_set_menu (GTK_OPTION_MENU (options->license_option_menu),
 			    menu);
 #endif
 
   /* Source Language. */
   frame = gtk_frame_new (_("Language:"));
+  /* Change this to 0 if you don't want the language option (C/C++/Perl). */
+#if 1
   gtk_widget_show (frame);
+#endif
   gtk_box_pack_start (GTK_BOX (general_options_vbox), frame, FALSE, TRUE, 4);
 
   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
@@ -386,7 +405,7 @@ glade_project_options_init (GladeProjectOptions * options)
 						      GladeLanguages[language]);
       gtk_widget_show (radio_button);
       gtk_box_pack_start (GTK_BOX (hbox), radio_button, FALSE, TRUE, 4);
-      group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_button));
+      group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio_button));
 
       options->language_buttons[language] = radio_button;
     }
@@ -402,6 +421,8 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_container_add (GTK_CONTAINER (frame), hbox);
 
   options->gnome_support = gtk_check_button_new_with_label (_("Enable Gnome Support"));
+  /* This can't be changed now. */
+  gtk_widget_set_sensitive (options->gnome_support, FALSE);
   gtk_widget_show (options->gnome_support);
   gtk_box_pack_start (GTK_BOX (hbox), options->gnome_support, TRUE, TRUE, 0);
   gtk_tooltips_set_tip (tooltips, options->gnome_support,
@@ -430,6 +451,14 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), c_options_vbox, label);
   gtk_container_set_border_width (GTK_CONTAINER (c_options_vbox), 7);
 
+  label = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (label), _("<b>Note:</b> for large applications the use of libglade is recommended."));
+  gtk_widget_set_size_request (label, 400, -1);
+  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+  gtk_widget_show (label);
+  gtk_box_pack_start (GTK_BOX (c_options_vbox), label, FALSE, TRUE, 4);
+
   hbox = gtk_hbox_new (TRUE, 4);
   gtk_widget_show (hbox);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 0);
@@ -561,6 +590,8 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_box_pack_start (GTK_BOX (hbox), options->main_header_entry,
 		      TRUE, TRUE, 0);
 
+  set_accessible_description (options->main_source_entry, _("Source file for interface creation functions")); 
+  set_accessible_description (options->main_header_entry, _("Header file for interface creation functions")); 
 
   /* Handler source file. */
   frame = gtk_frame_new (_("Signal Handler & Callback Functions:"));
@@ -605,6 +636,9 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_box_pack_start (GTK_BOX (hbox), options->handler_header_entry,
 		      TRUE, TRUE, 0);
 
+  set_accessible_description (options->handler_source_entry, _("Source file for signal handler and callback functions"));
+  set_accessible_description (options->handler_header_entry, _("Header file for signal handler and callback functions"));
+
   /* Support source file. */
   frame = gtk_frame_new (_("Support Functions:"));
   gtk_widget_show (frame);
@@ -648,6 +682,8 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_box_pack_start (GTK_BOX (hbox), options->support_header_entry,
 		      TRUE, TRUE, 0);
 
+  set_accessible_description (options->support_source_entry, _("Source file for support functions"));
+  set_accessible_description (options->support_header_entry, _("Header file for support functions")); 
 
   /*
    * libglade Options Page.
@@ -675,6 +711,16 @@ glade_project_options_init (GladeProjectOptions * options)
 
   row = 0;
 
+  label = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (label), _("<b>Note:</b> this option is deprecated - use intltool instead."));
+  gtk_widget_set_size_request (label, 400, -1);
+  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+  gtk_widget_show (label);
+  gtk_table_attach (GTK_TABLE (table), label,
+		    0, 3, row, row + 1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+  row++;
+
   /* Output translatable strings. */
   options->output_translatable_strings = gtk_check_button_new_with_label (_("Save Translatable Strings"));
   gtk_widget_show (options->output_translatable_strings);
@@ -711,13 +757,17 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_widget_show (hbbox);
   gtk_box_pack_start (GTK_BOX (main_vbox), hbbox, TRUE, TRUE, 0);
   gtk_button_box_set_layout (GTK_BUTTON_BOX (hbbox), GTK_BUTTONBOX_END);
-  gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbbox), 8);
+  gtk_box_set_spacing (GTK_BOX (hbbox), 8);
 
-#ifdef USE_GNOME
-  options->ok_button = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
-#else
-  options->ok_button = gtk_button_new_with_label (_("OK"));
-#endif
+  options->cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+  GTK_WIDGET_SET_FLAGS (options->cancel_button, GTK_CAN_DEFAULT);
+  gtk_widget_show (options->cancel_button);
+  gtk_container_add (GTK_CONTAINER (hbbox), options->cancel_button);
+  gtk_signal_connect_object (GTK_OBJECT (options->cancel_button), "clicked",
+			     GTK_SIGNAL_FUNC (gtk_widget_destroy),
+			     GTK_OBJECT (options));
+
+  options->ok_button = gtk_button_new_from_stock (GTK_STOCK_OK);
   GTK_WIDGET_SET_FLAGS (options->ok_button, GTK_CAN_DEFAULT);
   gtk_widget_show (options->ok_button);
   gtk_container_add (GTK_CONTAINER (hbbox), options->ok_button);
@@ -725,20 +775,10 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_signal_connect (GTK_OBJECT (options->ok_button), "clicked",
 		      GTK_SIGNAL_FUNC (glade_project_options_ok), options);
 
-#ifdef USE_GNOME
-  options->cancel_button = gnome_stock_button (GNOME_STOCK_BUTTON_CANCEL);
-#else
-  options->cancel_button = gtk_button_new_with_label (_("Cancel"));
-#endif
-  GTK_WIDGET_SET_FLAGS (options->cancel_button, GTK_CAN_DEFAULT);
-  gtk_widget_show (options->cancel_button);
-  gtk_container_add (GTK_CONTAINER (hbbox), options->cancel_button);
-  gtk_signal_connect_object (GTK_OBJECT (options->cancel_button), "clicked",
-			     GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			     GTK_OBJECT (options));
   gtk_signal_connect (GTK_OBJECT (options), "key_press_event",
 		      GTK_SIGNAL_FUNC (glade_util_check_key_is_esc),
 		      GINT_TO_POINTER (GladeEscDestroys));
+
   gtk_widget_grab_focus (options->directory_entry);
 }
 
@@ -765,12 +805,16 @@ glade_project_options_destroy (GtkObject *object)
   options = GLADE_PROJECT_OPTIONS (object);
 
   g_free (options->language_buttons);
+  options->language_buttons = NULL;
 
   /* FIXME: Maybe we need to disconnect the destroy signal handler added to
      the project. */
 
   if (options->filesel)
-    gtk_widget_destroy (options->filesel);
+    {
+      gtk_widget_destroy (options->filesel);
+      options->filesel = NULL;
+    }
 }
 
 
@@ -1040,7 +1084,7 @@ glade_project_options_generate_name (GladeProjectOptions *options)
 {
   gchar *directory, *project_name;
 
-  directory = gtk_entry_get_text (GTK_ENTRY (options->directory_entry));
+  directory = (char*) gtk_entry_get_text (GTK_ENTRY (options->directory_entry));
   project_name = glade_project_options_generate_project_name_from_directory (directory);
   options->auto_generation_level++;
   gtk_entry_set_text (GTK_ENTRY (options->name_entry), project_name);
@@ -1069,7 +1113,7 @@ glade_project_options_generate_program_name (GladeProjectOptions *options)
 {
   gchar *project_name, *program_name;
 
-  project_name = gtk_entry_get_text (GTK_ENTRY (options->name_entry));
+  project_name = (char*) gtk_entry_get_text (GTK_ENTRY (options->name_entry));
   program_name = glade_project_options_generate_program_name_from_project_name (project_name);
   options->auto_generation_level++;
   gtk_entry_set_text (GTK_ENTRY (options->program_name_entry), program_name);
@@ -1105,7 +1149,7 @@ glade_project_options_generate_xml_filename (GladeProjectOptions *options)
 {
   gchar *program_name, *xml_filename;
 
-  program_name = gtk_entry_get_text (GTK_ENTRY (options->program_name_entry));
+  program_name = (char*) gtk_entry_get_text (GTK_ENTRY (options->program_name_entry));
   xml_filename = glade_project_options_generate_xml_filename_from_program_name (program_name);
   options->auto_generation_level++;
   gtk_entry_set_text (GTK_ENTRY (options->xml_filename_entry), xml_filename);
@@ -1154,47 +1198,46 @@ glade_project_options_show_file_selection (GtkWidget *widget,
 
   if (options->filesel == NULL)
     {
-      options->filesel = gtk_file_selection_new (_("Select the Project Directory"));
-      gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (options->filesel)->ok_button),
-			  "clicked",
-			  GTK_SIGNAL_FUNC (glade_project_options_set_filename),
-			  options);
-
-      gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (options->filesel)->cancel_button),
-				 "clicked",
-				 GTK_SIGNAL_FUNC (glade_util_close_window),
-				 GTK_OBJECT (options->filesel));
-      gtk_signal_connect (GTK_OBJECT (options->filesel), "delete_event",
-			  GTK_SIGNAL_FUNC (glade_util_close_window_on_delete),
-			  NULL);
-      gtk_signal_connect (GTK_OBJECT (options->filesel), "key_press_event",
-		      GTK_SIGNAL_FUNC (glade_util_check_key_is_esc),
-		      GINT_TO_POINTER (GladeEscCloses));
+      options->filesel = gtk_file_chooser_dialog_new (_("Select the Project Directory"),
+						      GTK_WINDOW (options),
+						      GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER,
+						      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						      GTK_STOCK_OK, GTK_RESPONSE_OK,
+						      NULL);
+      gtk_dialog_set_default_response (GTK_DIALOG (options->filesel),
+				       GTK_RESPONSE_OK);
+ 
+      g_signal_connect (options->filesel, "response",
+			GTK_SIGNAL_FUNC (on_filesel_response), options);
+      g_signal_connect (options->filesel, "delete_event",
+			G_CALLBACK (gtk_true), NULL);
     }
 
-  filename = gtk_entry_get_text (GTK_ENTRY (options->directory_entry));
+  filename = (char*) gtk_entry_get_text (GTK_ENTRY (options->directory_entry));
   if (glade_util_file_exists (filename))
     {
-      gtk_file_selection_set_filename (GTK_FILE_SELECTION (options->filesel),
-				       filename);
+      glade_util_set_file_selection_filename (options->filesel, filename);
     }
-  if (GTK_IS_WINDOW (options))
-    gtk_window_set_transient_for (GTK_WINDOW (options->filesel),
-				  GTK_WINDOW (options));
-  gtk_widget_show (options->filesel);
-  gdk_window_show (options->filesel->window);
-  gdk_window_raise (options->filesel->window);
+
+  gtk_window_present (GTK_WINDOW (options->filesel));
 }
 
 
 static void
-glade_project_options_set_filename (GtkWidget *widget,
-				    GladeProjectOptions *options)
+on_filesel_response (GtkWidget *widget,
+		     gint response_id,
+		     GladeProjectOptions *options)
 {
   gchar *filename;
 
-  filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (options->filesel));
-  gtk_entry_set_text (GTK_ENTRY (options->directory_entry), filename);
+  if (response_id == GTK_RESPONSE_OK)
+    {
+      filename = glade_util_get_file_selection_filename (options->filesel);
+      if (filename)
+	gtk_entry_set_text (GTK_ENTRY (options->directory_entry), filename);
+      g_free (filename);
+    }
+
   glade_util_close_window (options->filesel);
 }
 
@@ -1303,7 +1346,7 @@ get_entry_text (GtkWidget *entry)
 {
   gchar *text;
 
-  text = gtk_entry_get_text (GTK_ENTRY (entry));
+  text = (char*) gtk_entry_get_text (GTK_ENTRY (entry));
   if (text && text[0] != '\0')
     return text;
   else
