@@ -112,10 +112,6 @@ gb_gnome_about_new (GbWidgetNewData *data)
   gtk_object_set_data (GTK_OBJECT (new_widget), TypeHint,
 		       GINT_TO_POINTER (GLADE_TYPE_HINT_DIALOG_INDEX));
 
-  /* Set the default comment string for the translator credits. */
-  glade_util_set_translation_properties (new_widget, TranslatorCredits,
-					 TRUE, "TRANSLATORS: Replace this string with your names, one name per line.", FALSE);
-
   return new_widget;
 }
 
@@ -151,7 +147,7 @@ gb_gnome_about_create_properties (GtkWidget * widget, GbWidgetCreateArgData * da
 static void
 gb_gnome_about_get_properties (GtkWidget *widget, GbWidgetGetArgData * data)
 {
-  char *translator_credits, *copyright, *comments, *translator_credits_output;
+  char *translator_credits, *copyright, *comments;
 
   gb_window_get_standard_properties (widget, data,
 				     NULL, NULL, NULL, NULL,
@@ -179,25 +175,20 @@ gb_gnome_about_get_properties (GtkWidget *widget, GbWidgetGetArgData * data)
 			 gtk_object_get_data (GTK_OBJECT (widget),
 					      Documenters));
 
-  /* If we are saving, and translator_credits isn't set but is translatable,
-     we save the string "translator_credits". Translators can then
-     replace this with their own names in the po files. */
-  translator_credits_output = translator_credits;
+  /* If we are saving, and translator_credits isn't set, we save the string
+     "translator_credits" and mark it as translatable. Translators can then
+     replace this with their own names in the po files. If it is set, we
+     output it as it is and don't mark it as translatable. */
   if (data->action == GB_SAVING
       && (!translator_credits || *translator_credits == '\0'))
     {
-      gchar *comments_text;
-      gboolean translatable, context;
-
-      glade_util_get_translation_properties (widget, TranslatorCredits,
-					     &translatable,
-					     &comments_text, &context);
-      if (translatable)
-	translator_credits_output = GLADE_TRANSLATORS_STRING;
+    gb_widget_output_translatable_text (data, TranslatorCredits,
+					GLADE_TRANSLATORS_STRING);
+    }
+  else
+    {
+      gb_widget_output_text (data, TranslatorCredits, translator_credits);
     }
-
-  gb_widget_output_translatable_text (data, TranslatorCredits,
-				      translator_credits_output);
 
   g_free (copyright);
   g_free (comments);
@@ -355,17 +346,15 @@ gb_gnome_about_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
   if (data->create_widget)
     {
       gchar *project_name = glade_project_get_name (data->project);
-      char *copyright, *about_comments, *translators;
+      char *copyright, *comments, *translators;
       char *authors, **authorsv, *documenters, **documentersv;
       gchar *logo_filename;
       char *pixbuf_name = NULL;
       gint i;
-      gboolean translatable, context;
-      gchar *comments;
 
       g_object_get (G_OBJECT (widget),
 		    "copyright", &copyright,
-		    "comments", &about_comments,
+		    "comments", &comments,
 		    "translator-credits", &translators,
 		    NULL);
 
@@ -410,27 +399,19 @@ gb_gnome_about_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 	  source_add_decl (data, "  const gchar *documenters[] = { NULL };\n");
 	}
 
-      /* If translators is set, then we use that specific string.
-	 If it is not set, then if gettext support is enabled we output code
-	 to call gettext to translate the special "translator_credits" string,
-	 and use that if it is translated. */
-      glade_util_get_translation_properties (widget, TranslatorCredits,
-					     &translatable,
-					     &comments, &context);
+      /* If translators is set, then we use that specific string without
+	 translation. If it is not set or empty, then if gettext support is
+	 enable we output code to call gettext to translate the special
+	 "translator_credits" string, and use that if it is translated. */
       if (translators && translators[0])
 	{
-	  source_add_translator_comments_to_buffer (data, GLADE_DECLARATIONS, translatable, comments);
 	  source_add_decl (data, "  gchar *translators = %s;\n",
 			   source_make_string (translators, FALSE));
 	}
-      else if (data->use_gettext && translatable)
+      else if (data->use_gettext)
 	{
-	  if (!comments || comments[0] == '\0')
-	    comments = "TRANSLATORS: Replace this string with your names, one name per line.";
-
-	  source_add_translator_comments_to_buffer (data, GLADE_DECLARATIONS,
-						    translatable, comments);
 	  source_add_decl (data,
+			   "  /* TRANSLATORS: Replace this string with your names, one name per line. */\n"
 			   "  gchar *translators = _(\"%s\");\n",
 			   GLADE_TRANSLATORS_STRING);
 
@@ -460,25 +441,14 @@ gb_gnome_about_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 		  data->wname,
 		  source_make_string (project_name ? project_name : "",
 				      FALSE));
-
-      glade_util_get_translation_properties (widget, Copyright, &translatable,
-					     &comments, &context);
-      source_add_translator_comments (data, translatable, comments);
       source_add (data,
 		  "                        %s,\n",
-		  source_make_string_full (copyright ? copyright : "",
-					   data->use_gettext && translatable,
-					   context));
-
-      glade_util_get_translation_properties (widget, Comments, &translatable,
-					     &comments, &context);
-      source_add_translator_comments (data, translatable, comments);
+		  source_make_string (copyright ? copyright : "",
+				      data->use_gettext));
       source_add (data,
 		  "                        %s,\n",
-		  source_make_string_full (about_comments ? about_comments : "",
-					   data->use_gettext && translatable,
-					   context));
-
+		  source_make_string (comments ? comments : "",
+				      data->use_gettext));
       source_add (data,
 		  "                        authors,\n"
 		  "                        documenters,\n"
@@ -490,7 +460,7 @@ gb_gnome_about_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 
       g_free (pixbuf_name);
       g_free (copyright);
-      g_free (about_comments);
+      g_free (comments);
       g_free (translators);
     }
 
